==> vee_2.4-2.tar.gz: vee-2.4/src/child/terminal.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os, base64, marshal
import child, __BASIC__, __VTE__, TAB, Conf, i18n, func, Menu

_ = i18n.gettext()

class egg (__VTE__.egg) :

	CHILD_TYPE = child.TYPE_TERMINAL
	FORK_COMMAND = "/bin/bash"
	ARGUMENT = ("-l", )

	def make (self) :
		__VTE__.egg.make(self)

		self.store_recent()

	def fork_command (self) :
		if self.SETTING.has_key("command") and \
				self.SETTING["command"].strip() :
			__fork_command = self.SETTING["command"]
		else :
			__fork_command = \
				self.GCONF_CLIENT.get_value(Conf.SCHEMA["command-terminal"]["key"])

		__parsed_command = \
			func.parse_command_line_argument(__fork_command)

		self.ARGUMENT = __parsed_command["argument"]
		self.ENVIRONMENT = __parsed_command["environment"]
		self.FORK_COMMAND = __parsed_command["command"]

		__VTE__.egg.fork_command(self)

	def get_title (self) :
		__t = __VTE__.egg.get_title(self)

		if not __t : return str()

		__t0 = "".join(__t.split(":")[1:]).strip()

		if len(__t0) < 1 :
			__title = __t
		else :
			__title = __t0

		# save directory to self.DIRECTORY
		self.DIRECTORY = __title

		# remember the last directory path.
		self.GCONF_CLIENT.set_value_by_conf( \
			"last-directory-path", \
			__title \
		)

		return __title

	def attach_popupmenu (self) :
		callback_functions = { \
			"reset" : self.reset, \
			"get_directory" : self.get_directory \
		}

		self.WIDGET.connect( \
			"button-press-event", \
			Menu.on_show_popup_terminal, \
			self.WIDGET, \
			callback_functions \
		)

	def get_directory (self) :
		return self.DIRECTORY

	def exit (self) :
		self.WIDGET.feed_child("\n")
		self.WIDGET.feed_child("exit\n")

		__VTE__.egg.exit(self)

	def store_recent (self) :
		__data = self.GCONF_CLIENT.get_value( \
			Conf.SCHEMA["recent-opened-directories"]["key"])

		list_directory = list()
		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				list_directory = __data1
		except EOFError :
			pass

		if self.DIRECTORY in list_directory :
			# remove old one and make new one be 1st.
			del(list_directory[list_directory.index(self.DIRECTORY)])

		list_directory = [self.DIRECTORY,] + list_directory

		__data = marshal.dumps(list_directory)
		__data0 = base64.encodestring(__data)

		self.GCONF_CLIENT.set_value_by_conf( \
			"recent-opened-directories", \
			__data0 \
		)

class tab (__VTE__.tab) :

	LABEL_NAME = _("Terminal")

	def __init__ (self, state, **kwargs) :

		__VTE__.tab.__init__(self, state, **kwargs)

	def getEgg (self) :
		# get the latest directory path.
		if not self.KWARGS.has_key("directory") :
			__dirname = \
				self.GCONF_CLIENT.get_value(Conf.SCHEMA["last-directory-path"]["key"])
			if os.path.exists(__dirname) :
				self.KWARGS["directory"] = __dirname
			else :
				__dirname = os.getenv("HOME")

		self.EGG = egg(**self.KWARGS)
		self.EGG.make()

	def make (self) :
		self.getEgg()

		self.WIDGET = TAB.One(state=self.STATE)
		self.WIDGET.STR_TAB_NAME = self.LABEL_NAME
		self.WIDGET.addVTE(self.EGG)

		self.append_tab()
		self.connect()

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "terminal.py"

==> vee_2.4-6.tar.gz: vee-2.4/src/child/terminal.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import os, base64, marshal
import child, __BASIC__, __VTE__, TAB, Conf, i18n, func, Menu

_ = i18n.gettext()

class egg (__VTE__.egg) :

	CHILD_TYPE = child.TYPE_TERMINAL
	FORK_COMMAND = "/bin/bash"
	ARGUMENT = ("-l", )

	def make (self) :
		__VTE__.egg.make(self)

		self.store_recent()

	def fork_command (self) :
		__fork_command = self.SETTING.get_command_terminal()

		__parsed_command = \
			func.parse_command_line_argument(__fork_command)

		self.ARGUMENT = __parsed_command["argument"]
		self.ENVIRONMENT = __parsed_command["environment"]
		self.FORK_COMMAND = __parsed_command["command"]

		__VTE__.egg.fork_command(self)

	def get_title (self) :
		__t = __VTE__.egg.get_title(self)

		if not __t : return str()

		__t0 = "".join(__t.split(":")[1:]).strip()

		if len(__t0) < 1 :
			__title = __t
		else :
			__title = __t0

		# save directory to self.DIRECTORY
		self.DIRECTORY = __title

		# remember the last directory path.
		self.GCONF_CLIENT.set_value_by_conf( \
			"last-directory-path", \
			__title \
		)

		return __title

	def attach_popupmenu (self) :
		callback_functions = { \
			"reset" : self.reset, \
			"get_directory" : self.get_directory \
		}

		self.WIDGET.connect( \
			"button-press-event", \
			Menu.on_show_popup_terminal, \
			self.WIDGET, \
			callback_functions \
		)

	def get_directory (self) :
		return self.DIRECTORY

	def exit (self) :
		self.WIDGET.feed_child("\n")
		self.WIDGET.feed_child("exit\n")

		__VTE__.egg.exit(self)

	def store_recent (self) :
		__data = self.GCONF_CLIENT.get_value( \
			Conf.SCHEMA["recent-opened-directories"]["key"])

		list_directory = list()
		try :
			__data0 = base64.decodestring(__data)
			__data1 = marshal.loads(__data0)

			if type(__data1) is list :
				list_directory = __data1
		except EOFError :
			pass

		if self.DIRECTORY in list_directory :
			# remove old one and make new one be 1st.
			del(list_directory[list_directory.index(self.DIRECTORY)])

		list_directory = [self.DIRECTORY,] + list_directory

		__data = marshal.dumps(list_directory)
		__data0 = base64.encodestring(__data)

		self.GCONF_CLIENT.set_value_by_conf( \
			"recent-opened-directories", \
			__data0 \
		)

class tab (__VTE__.tab) :

	LABEL_NAME = _("Terminal")

	def __init__ (self, state, **kwargs) :

		__VTE__.tab.__init__(self, state, **kwargs)

	def getEgg (self) :
		# get the latest directory path.
		if not self.KWARGS.has_key("directory") :
			__dirname = \
				self.GCONF_CLIENT.get_value(Conf.SCHEMA["last-directory-path"]["key"])
			if os.path.exists(__dirname) :
				self.KWARGS["directory"] = __dirname
			else :
				__dirname = os.getenv("HOME")

		self.EGG = egg(**self.KWARGS)
		self.EGG.make()

	def make (self) :
		self.getEgg()

		self.WIDGET = TAB.One(state=self.STATE)
		self.WIDGET.STR_TAB_NAME = self.LABEL_NAME
		self.WIDGET.addVTE(self.EGG)

		self.append_tab()
		self.connect()

"""
Description
-----------


ChangeLog
---------


Usage
-----


"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "terminal.py"
